# Examples

Build on the basic template above with Bootstrap's many components. We encourage you to customize and adapt Bootstrap to suit your individual project's needs.

## Using the framework

### Starter template

Nothing but the basics: compiled CSS and JavaScript along with a container.

### Bootstrap theme

Load the optional Bootstrap theme for a visually enhanced experience.

### Grids

Multiple examples of grid layouts with all four tiers, nesting, and more.

### Jumbotron

Build around the jumbotron with a navbar and some basic grid columns.

### Narrow jumbotron

Build a more custom page by narrowing the default container and jumbotron.

## Navbars in action

### Navbar

Super basic template that includes the navbar along with some additional content.

### Static top navbar

Super basic template with a static top navbar along with some additional content.

### Fixed navbar

Super basic template with a fixed top navbar along with some additional content.

## Custom components

### Cover

A one-page template for building simple and beautiful home pages.

### Carousel

Customize the navbar and carousel, then add some new components.

### Blog

Simple two-column blog layout with custom navigation, header, and type.

### Dashboard

Basic structure for an admin dashboard with fixed sidebar and navbar.

### Sign-in page

Custom form layout and design for a simple sign in form.

### Justified nav

Create a custom navbar with justified links. Heads up! Not too Safari friendly.

### Sticky footer

Attach a footer to the bottom of the viewport when the content is shorter than it.

### Sticky footer with navbar

Attach a footer to the bottom of the viewport with a fixed navbar at the top.

## Experiments

### Non-responsive Bootstrap

Easily disable the responsiveness of Bootstrap per our docs.

### Off-canvas

Build a toggleable off-canvas navigation menu for use with Bootstrap.